Wago
====

Welcome to `AsyncWago <http://github.com/M-o-a-T/asyncwago>`__!

This library controls access to I/O on Wago controllers.
These are industrial devices with various analog and digital extension modules.
They run a basic embedded Linux. Older models don't even have a MMU.

A small control program needs to run on the controller.
You can get its source from the `Wago Firmware <http://github.com/M-o-a-T/wago-firmware>`__ archive.

License: GPLv3 as published by the Free Software Foundation, or (at your option) any later version

